#!/usr/local/bin/perl
#
# SYNTAX:
#	check_swap -w w{%} -c c{%}
#
# DESCRIPTION:
# 	Quickie, to use swap -s for Nagios checking
# 

use Getopt::Std;

getopts('w:c:');

die "Must set critical and warning thresholds" unless ($opt_c && $opt_w);

if ($opt_w =~ /^(\d+)%$/) {
	$W_PERCENTAGE = $1;
} elsif ($opt_w =~ /^(\d+)$/) {
	$W_THRESHOLD = $1;
}

if ($opt_c =~ /^(\d+)%$/) {
} elsif ($opt_c =~ /^(\d+)$/) {
	$C_THRESHOLD = $1;
}

$output = `/usr/sbin/swap -s`;
($used, $free) = ($output =~ /^total: \d+k \w+ \w+ \+ \w+ \w+ = (\d+)k \w+, (\d+)k \w+$/);

$total = $used + $free;
$usedp = $used / $total * 100;
$freep = $free / $total * 100;

if ($freep <= $C_PERCENTAGE || $free <= $C_THRESHOLD) {
	$state = "CRITICAL";
	$exit = 2;
} elsif ($freep <= $W_PERCENTAGE || $free <= $W_THRESHOLD) {
	$state = "WARNING";
	$exit = 1;
} else {
	$state = "OK";
	$exit = 0;
}
printf "SWAP $state - %dk (%2.1f%) free$/", $free, $freep;
exit $exit;
